webbpsf\_ext.opds
=================

.. automodule:: webbpsf_ext.opds

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      OPDFile_to_HDUList
      plot_im
      plot_opd
      slew_time
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      OTE_WFE_Drift_Model
   
   

   
   
   



